/* ########################## Empirical Application ############################
# Paper: "Davezies, D'Haultfoeuille, Mugnier (2022)"
# File: 1_narrow_sample_program.do 
# Task: This code is adapted from Brender and Drazen (2008). It outputs
		- narrow_data.csv: narrow sample;
		- coeffs_narrow.xlsx, LOGIT_avar_spe_1_narrow.xlsx, and 
		LOGITFE_avar_spe_2_narrow.xlsx: estimated coefficients and 
		variance-covariance matrices for the cross-sectional and fixed effects 
		logit models corresponding to columns 1 and 2 in Table 3 of Brender and 
		Drazen (2008). In contrast to Brender and Drazen (2008), we compute 
		clustered standard errors by country in column 1 to account for serial 
		correlation.
		
# Author: Martin Mugnier, martin.mugnier@ensae.fr
# Date: October 5, 2022
################################################################################
*/

clear	 
	
/* set path to replication folder */	 
cd "W:\Documents\SIMULATIONS CLUSTER\application_extension_logit_summer_2022"
use reelect_data.dta	
		
/* generate narrow sample as in Brender and Drazen (2008) */
quietly: probit reelect2 ddef3_n ddef1 gdppc_gr2		
generate f2 = 1 if e(sample)		 
drop if f2!=1		 
drop if inf==.	

/* export narrow sample to a .csv file */
export delimited using "narrow_data.csv", replace

/* replicate Table 3 (columns 1 and 2) in Brender and Drazen (2008) */
quietly: tab code, gen (ca) 
quietly: logit reelect2 ddef3_n ddef1 gdppc_gr2 nd maj ca* if dev==1	
	
/* column 1 (with clustered standard errors at the country level) */
logit reelect2 ddef3_n ddef1 gdppc_gr2 nd maj if dev==1 & e(sample)==1, vce(cluster code) 
matrix b1 = e(b)
matrix V=e(V)
putexcel set LOGIT_avar_spe_1_narrow
putexcel A1 = matrix(V)
putexcel close

/* column 2 */
xtlogit reelect2 ddef3_n ddef1 gdppc_gr2 nd maj if dev==1, fe i(code)
matrix b2 = e(b)
matrix V=e(V)
putexcel set LOGITFE_avar_spe_2_narrow
putexcel A1 = matrix(V)
putexcel close
drop ca* 

/* export coefficients */
putexcel set coeffs_narrow
putexcel A1 = matrix(b1)
putexcel A2 = matrix(b2)
putexcel close 	
