/* ########################## Empirical Application ############################
# Paper: "Davezies, D'Haultfoeuille, Mugnier (2022)"
# File: 2_expanded_sample_program.do 
# Task: This code is adapted from Brender and Drazen (2008). It outputs
		- expanded_data.csv: expanded sample;
		- coeffs_expanded.xlsx, LOGIT_avar_spe_5_expanded.xlsx, and 
		LOGITFE_avar_spe_6_expanded.xlsx: estimated coefficients and 
		variance-covariance matrices for the cross-sectional and fixed effects 
		logit models corresponding to columns 5 and 6 in Table 3 of Brender and 
		Drazen (2008). In contrast to Brender and Drazen (2008), we compute 
		clustered standard errors by country in column 5 to account for serial 
		correlation.
		
# Author: Martin Mugnier, martin.mugnier@ensae.fr
# Date: October 5, 2022
################################################################################
*/

clear		
			
/* set path to replication folder */	 
cd "W:\Documents\SIMULATIONS CLUSTER\application_extension_logit_summer_2022"
use reelect_data.dta	

/* generate expanded sample as in Brender and Drazen (2008) */
probit reelect3 ddef3_n ddef1 gdppc_gr3		
generate f3 = 1 if e(sample)
drop if f3!=1
drop if inf==.

/* export expanded sample to a .csv file */
export delimited using "expanded_data.csv", replace

/* replicate Table 3 (columns 5 and 6) in Brender and Drazen (2008) */
quietly: tab code, gen (ca)
quietly: logit reelect3 ddef3_n ddef1 gdppc_gr3 nd maj ca* if dev==1

/* column 5 (with clustered standard errors at the country level) */
logit reelect3 ddef3_n ddef1 gdppc_gr3 nd maj if dev==1 & e(sample)==1, vce(cluster code)
matrix b1 = e(b)
matrix V=e(V)
putexcel set LOGIT_avar_spe_5_expanded
putexcel A1 = matrix(V)
putexcel close

/* column 6 */
xtlogit reelect3 ddef3_n ddef1 gdppc_gr3 nd maj if dev==1, fe i(code)
matrix b2 = e(b)
matrix V=e(V)
putexcel set LOGITFE_avar_spe_6_expanded
putexcel A1 = matrix(V)
putexcel close
drop ca*

/* Export coefficients */
putexcel set coeffs_expanded
putexcel A1 = matrix(b1)
putexcel A2 = matrix(b2)
putexcel close 	